TscGridRow class
- Inheritance
-
- Object
- TscLabelCommand
- TscGridRow
Constructors
-
TscGridRow({required int y, required List<
TscGridCol> children, int gutter = 12, int totalColumns = 12}) -
const
Properties
-
children
→ List<
TscGridCol> -
final
- gutter → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalColumns → int
-
final
- y → int
-
final
Methods
-
apply(
TscGenerator generator) → FutureOr< void> -
inherited
-
applyWithContext(
TscGenerator generator, TscBuildContext context) → Future< TscLayoutResult> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited