TscTextStyle class
Constructors
- TscTextStyle({TscFont font = TscFont.font3, TscRotation rotation = TscRotation.angle0, int xMultiplier = 1, int yMultiplier = 1, TscTextAlignment? alignment})
-
const
Properties
- alignment → TscTextAlignment?
-
final
- font → TscFont
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rotation → TscRotation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- xMultiplier → int
-
final
- yMultiplier → int
-
final
Methods
-
copyWith(
{TscFont? font, TscRotation? rotation, int? xMultiplier, int? yMultiplier, TscTextAlignment? alignment}) → TscTextStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited